@@ -44,6 +44,7 @@ __all__ = (
     "AutocompleteContext",
     "ModalContext",
     "PrefixedContext",
+    "HybridContext",
     "SendableContext",
 )
 
@@ -664,6 +665,203 @@ class PrefixedContext(Context, SendMixin):
         return await self._client.http.create_message(message_payload, self.channel.id, files=files)
 
 
+@define
+class HybridContext(Context):
+    """
+    Represents the context for hybrid commands, a slash command that can also be used as a prefixed command.
+
+    This attempts to create a compatibility layer to allow contexts for an interaction or a message to be used seamlessly.
+    """
+
+    deferred: bool = field(default=False, metadata=docs("Is this context deferred?"))
+    responded: bool = field(default=False, metadata=docs("Have we responded to this?"))
+    app_permissions: Permissions = field(
+        default=0, converter=Permissions, metadata=docs("The permissions this context has")
+    )
+
+    _interaction_context: Optional[InteractionContext] = field(default=None)
+    _prefixed_context: Optional[PrefixedContext] = field(default=None)
+
+    @classmethod
+    def from_interaction_context(cls, context: InteractionContext) -> "HybridContext":
+        return cls(
+            client=context._client,  # type: ignore
+            interaction_context=context,  # type: ignore
+            invoke_target=context.invoke_target,
+            command=context.command,
+            args=context.args,
+            kwargs=context.kwargs,
+            author=context.author,
+            channel=context.channel,
+            guild_id=context.guild_id,
+            deferred=context.deferred,
+            responded=context.responded,
+            app_permissions=context.app_permissions,
+        )
+
+    @classmethod
+    def from_prefixed_context(cls, context: PrefixedContext) -> "HybridContext":
+        # this is a "best guess" on what the permissions are
+        # this may or may not be totally accurate
+        if hasattr(context.channel, "permissions_for"):
+            app_permissions = context.channel.permissions_for(context.guild.me)  # type: ignore
+        elif context.channel.type in {10, 11, 12}:  # it's a thread
+            app_permissions = context.channel.parent_channel.permissions_for(context.guild.me)  # type: ignore
+        else:
+            # this is what happens with interaction contexts in dms
+            app_permissions = 0
+
+        return cls(
+            client=context._client,  # type: ignore
+            prefixed_context=context,  # type: ignore
+            invoke_target=context.invoke_target,
+            command=context.command,
+            args=context.args,
+            kwargs=context.kwargs,  # this is usually empty
+            author=context.author,
+            channel=context.channel,
+            guild_id=context.guild_id,
+            message=context.message,
+            app_permissions=app_permissions,
+        )
+
+    @property
+    def inner_context(self) -> InteractionContext | PrefixedContext:
+        """
+        Returns the context powering the current hybrid context.
+
+        This can be used for scope-specific actions, like sending modals in an interaction.
+        """
+        return self._interaction_context or self._prefixed_context  # type: ignore
+
+    @property
+    def ephemeral(self) -> bool:
+        """Returns if responses to this interaction are ephemeral, if this is an interaction. Otherwise, returns False."""
+        return self._interaction_context.ephemeral if self._interaction_context else False
+
+    @property
+    def expires_at(self) -> Optional[Timestamp]:
+        """The timestamp the context is expected to expire at, or None if the context never expires."""
+        if not self._interaction_context:
+            return None
+
+        if self.responded:
+            return Timestamp.from_snowflake(self._interaction_context.interaction_id) + datetime.timedelta(minutes=15)
+        return Timestamp.from_snowflake(self._interaction_context.interaction_id) + datetime.timedelta(seconds=3)
+
+    @property
+    def expired(self) -> bool:
+        """Has the context expired yet?"""
+        return Timestamp.utcnow() >= self.expires_at if self.expires_at else False
+
+    @property
+    def invoked_name(self) -> str:
+        return (
+            self.command.get_localised_name(self._interaction_context.locale)
+            if self._interaction_context
+            else self.invoke_target
+        )
+
+    async def defer(self, ephemeral: bool = False) -> None:
+        """
+        Either defers the response (if used in an interaction) or triggers a typing indicator for 10 seconds (if used for messages).
+
+        Args:
+            ephemeral: Should the response be ephemeral? Only applies to responses for interactions.
+
+        """
+        if self._interaction_context:
+            await self._interaction_context.defer(ephemeral=ephemeral)
+        else:
+            await self.channel.trigger_typing()
+
+        self.deferred = True
+
+    async def reply(
+        self,
+        content: Optional[str] = None,
+        embeds: Optional[Union[List[Union["Embed", dict]], Union["Embed", dict]]] = None,
+        embed: Optional[Union["Embed", dict]] = None,
+        **kwargs,
+    ) -> "Message":
+        """
+        Reply to this message, takes all the same attributes as `send`.
+
+        For interactions, this functions the same as `send`.
+        """
+        kwargs = locals()
+        kwargs.pop("self")
+        extra_kwargs = kwargs.pop("kwargs")
+        kwargs |= extra_kwargs
+
+        if self._interaction_context:
+            result = await self._interaction_context.send(**kwargs)
+        else:
+            kwargs.pop("ephemeral", None)
+            result = await self._prefixed_context.reply(**kwargs)  # type: ignore
+
+        self.responded = True
+        return result
+
+    async def send(
+        self,
+        content: Optional[str] = None,
+        embeds: Optional[Union[List[Union["Embed", dict]], Union["Embed", dict]]] = None,
+        embed: Optional[Union["Embed", dict]] = None,
+        components: Optional[
+            Union[
+                List[List[Union["BaseComponent", dict]]],
+                List[Union["BaseComponent", dict]],
+                "BaseComponent",
+                dict,
+            ]
+        ] = None,
+        stickers: Optional[Union[List[Union["Sticker", "Snowflake_Type"]], "Sticker", "Snowflake_Type"]] = None,
+        allowed_mentions: Optional[Union["AllowedMentions", dict]] = None,
+        reply_to: Optional[Union["MessageReference", "Message", dict, "Snowflake_Type"]] = None,
+        file: Optional[Union["File", "IOBase", "Path", str]] = None,
+        tts: bool = False,
+        flags: Optional[Union[int, "MessageFlags"]] = None,
+        ephemeral: bool = False,
+        **kwargs,
+    ) -> "Message":
+        """
+        Send a message.
+
+        Args:
+            content: Message text content.
+            embeds: Embedded rich content (up to 6000 characters).
+            embed: Embedded rich content (up to 6000 characters).
+            components: The components to include with the message.
+            stickers: IDs of up to 3 stickers in the server to send in the message.
+            allowed_mentions: Allowed mentions for the message.
+            reply_to: Message to reference, must be from the same channel.
+            files: Files to send, the path, bytes or File() instance, defaults to None. You may have up to 10 files.
+            file: Files to send, the path, bytes or File() instance, defaults to None. You may have up to 10 files.
+            tts: Should this message use Text To Speech.
+            suppress_embeds: Should embeds be suppressed on this send
+            flags: Message flags to apply.
+            ephemeral: Should this message be sent as ephemeral (hidden) - only works with interactions.
+
+        Returns:
+            New message object that was sent.
+
+        """
+        kwargs = locals()
+        kwargs.pop("self")
+        extra_kwargs = kwargs.pop("kwargs")
+        kwargs |= extra_kwargs
+
+        if self._interaction_context:
+            result = await self._interaction_context.send(**kwargs)
+        else:
+            kwargs.pop("ephemeral", None)
+            result = await self._prefixed_context.send(**kwargs)  # type: ignore
+
+        self.responded = True
+        return result
+
+
 @runtime_checkable
 class SendableContext(Protocol):
     """
